@@ -1,11 +1,11 @@
 # Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
-
-from typing import Dict, Optional
+# pyre-ignore-all-errors[2,3]
+from typing import Any, Dict, Iterable, Iterator, Tuple
 
 from tabulate import tabulate
 
 
-class Registry(object):
+class Registry(Iterable[Tuple[str, Any]]):
     """
     The registry that provides name -> object mapping, to support third-party
     users' custom modules.
@@ -37,9 +37,9 @@ class Registry(object):
             name (str): the name of this registry
         """
         self._name: str = name
-        self._obj_map: Dict[str, object] = {}
+        self._obj_map: Dict[str, Any] = {}
 
-    def _do_register(self, name: str, obj: object) -> None:
+    def _do_register(self, name: str, obj: Any) -> None:
         assert (
             name not in self._obj_map
         ), "An object named '{}' was already registered in '{}' registry!".format(
@@ -47,25 +47,25 @@ class Registry(object):
         )
         self._obj_map[name] = obj
 
-    def register(self, obj: object = None) -> Optional[object]:
+    def register(self, obj: Any = None) -> Any:
         """
         Register the given object under the the name `obj.__name__`.
         Can be used as either a decorator or not. See docstring of this class for usage.
         """
         if obj is None:
             # used as a decorator
-            def deco(func_or_class: object) -> object:
-                name = func_or_class.__name__  # pyre-ignore
+            def deco(func_or_class: Any) -> Any:
+                name = func_or_class.__name__
                 self._do_register(name, func_or_class)
                 return func_or_class
 
             return deco
 
         # used as a function call
-        name = obj.__name__  # pyre-ignore
+        name = obj.__name__
         self._do_register(name, obj)
 
-    def get(self, name: str) -> object:
+    def get(self, name: str) -> Any:
         ret = self._obj_map.get(name)
         if ret is None:
             raise KeyError(
@@ -83,5 +83,8 @@ class Registry(object):
         )
         return "Registry of {}:\n".format(self._name) + table
 
+    def __iter__(self) -> Iterator[Tuple[str, Any]]:
+        return iter(self._obj_map.items())
+
     # pyre-fixme[4]: Attribute must be annotated.
     __str__ = __repr__
